# Pose3D - Position and Orientation Python Library

Handling 2D and 3D poses as well as transformations between reference frames.

## Documentation
Visit page: <https://johnhal.gitlab.io/pose_python>

## Installing Library
This ibrary is freely available at the Python Package Index. You can install the latest version onto your machine with the following command:

``` bash
pip install pose3d --upgrade
```
